---
title: <span class="badge object-type-scalar"></span> Nanoseconds
---
# <span class="badge object-type-scalar"></span> Nanoseconds

Time: nanoseconds (ns)

## Definition

```python
# Time: nanoseconds (ns)
Nanoseconds: typing.Literal["ns"] = "ns"
```
